================
Django MarkdownX
================

|PyPi_Version| |PyPi_Status| |Build_Status| |Format| |Supported_versions_of_Python| |Supported_versions_of_Django| |License|

Django MarkdownX is a comprehensive Markdown_ plugin built for Django_, the renowned high-level Python web framework, with flexibility, extensibility, and ease-of-use at its core.

Documentation
=============
https://neutronx.github.io/django-markdownx/


Key features
============

* Raw editing.
* Live preview.
* Drag & drop image uploads (automatically stored in the designated location in the *Media* directory).
* Customizable image insertion tag.
* Definition of maximum size for an image.
* Definition of acceptable image formats (PNG, JPEG, SVG).
* Image manipulations (compression, size reduction, cropping, upscaling).
* Pre- and post- text modification.
* Easy template customization, layout modification, and personalization.
* Multiple editors per page.
* Django Admin support.

Preview
=======

.. image:: https://github.com/neutronX/django-markdownx/raw/master/django-markdownx-preview.gif?raw=true
   :target: https://github.com/neutronX/django-markdownx
   :align: center
   :alt: django-markdownx preview

*(using Bootstrap for layout and styling)*

.. _Markdown: https://en.wikipedia.org/wiki/Markdown
.. _Django: https://www.djangoproject.com

.. |PyPi_Version| image:: https://img.shields.io/pypi/v/django-markdownx.svg
.. |PyPi_Status| image:: https://img.shields.io/pypi/status/django-markdownx.svg
.. |Build_Status| image:: https://img.shields.io/travis/neutronX/django-markdownx.svg
.. |Format| image:: https://img.shields.io/pypi/format/django-markdownx.svg
.. |Supported_versions_of_Python| image:: https://img.shields.io/pypi/pyversions/django-markdownx.svg
.. |Supported_versions_of_Django| image:: https://img.shields.io/badge/Django-1.8,%201.9,%201.10,%201.11,%202.0,%202.1-green.svg
.. |License| image:: https://img.shields.io/pypi/l/django-markdownx.svg
